Crate lambda_lw_http_router_macro

Crate lambda_lw_http_router_macro 

Procedural macros for the lambda-lw-http-router crate.

Note: This is a proc-macro implementation crate for lambda-lw-http-router and is not meant to be used directly. Please use the main crate instead.

The macros in this crate are re-exported by the main crate, and using them directly may lead to version conflicts or other issues. Additionally, this crate’s API is not guaranteed to be stable between minor versions.

Usage

Instead of using this crate directly, use the main crate:

[dependencies]
lambda-lw-http-router = "0.5.0"

See the lambda-lw-http-router documentation for more information on how to use the router.

Attribute Macros

route
Defines a route handler for Lambda HTTP events.